==> huaweicloudsdkgaussdb-3.1.111-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/click_house_node_info_datastore.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ClickHouseNodeInfoDatastore:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'type': 'str',
        'version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, id=None, type=None, version=None):
        """ClickHouseNodeInfoDatastore

        The model defined in huaweicloud sdk

        :param id: 引擎ID。
        :type id: str
        :param type: 引擎类型，现在只支持click-house。
        :type type: str
        :param version: 引擎版本。
        :type version: str
        """
        
        

        self._id = None
        self._type = None
        self._version = None
        self.discriminator = None

        self.id = id
        self.type = type
        self.version = version

    @property
    def id(self):
        """Gets the id of this ClickHouseNodeInfoDatastore.

        引擎ID。

        :return: The id of this ClickHouseNodeInfoDatastore.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ClickHouseNodeInfoDatastore.

        引擎ID。

        :param id: The id of this ClickHouseNodeInfoDatastore.
        :type id: str
        """
        self._id = id

    @property
    def type(self):
        """Gets the type of this ClickHouseNodeInfoDatastore.

        引擎类型，现在只支持click-house。

        :return: The type of this ClickHouseNodeInfoDatastore.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ClickHouseNodeInfoDatastore.

        引擎类型，现在只支持click-house。

        :param type: The type of this ClickHouseNodeInfoDatastore.
        :type type: str
        """
        self._type = type

    @property
    def version(self):
        """Gets the version of this ClickHouseNodeInfoDatastore.

        引擎版本。

        :return: The version of this ClickHouseNodeInfoDatastore.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ClickHouseNodeInfoDatastore.

        引擎版本。

        :param version: The version of this ClickHouseNodeInfoDatastore.
        :type version: str
        """
        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClickHouseNodeInfoDatastore):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.158-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/click_house_node_info_datastore.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ClickHouseNodeInfoDatastore:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'type': 'str',
        'version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'version': 'version'
    }

    def __init__(self, id=None, type=None, version=None):
        r"""ClickHouseNodeInfoDatastore

        The model defined in huaweicloud sdk

        :param id: 引擎ID。
        :type id: str
        :param type: 引擎类型，现在只支持click-house。
        :type type: str
        :param version: 引擎版本。
        :type version: str
        """
        
        

        self._id = None
        self._type = None
        self._version = None
        self.discriminator = None

        self.id = id
        self.type = type
        self.version = version

    @property
    def id(self):
        r"""Gets the id of this ClickHouseNodeInfoDatastore.

        引擎ID。

        :return: The id of this ClickHouseNodeInfoDatastore.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        r"""Sets the id of this ClickHouseNodeInfoDatastore.

        引擎ID。

        :param id: The id of this ClickHouseNodeInfoDatastore.
        :type id: str
        """
        self._id = id

    @property
    def type(self):
        r"""Gets the type of this ClickHouseNodeInfoDatastore.

        引擎类型，现在只支持click-house。

        :return: The type of this ClickHouseNodeInfoDatastore.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        r"""Sets the type of this ClickHouseNodeInfoDatastore.

        引擎类型，现在只支持click-house。

        :param type: The type of this ClickHouseNodeInfoDatastore.
        :type type: str
        """
        self._type = type

    @property
    def version(self):
        r"""Gets the version of this ClickHouseNodeInfoDatastore.

        引擎版本。

        :return: The version of this ClickHouseNodeInfoDatastore.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        r"""Sets the version of this ClickHouseNodeInfoDatastore.

        引擎版本。

        :param version: The version of this ClickHouseNodeInfoDatastore.
        :type version: str
        """
        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClickHouseNodeInfoDatastore):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
